/* A small complete program for testing the debug monitor. On an
   STK200 board it will do some flashing of the LEDs PB0 to PB3. */

/* Needs some header files from avr-libc for the bit manipulation
   macros etc. */

#include <io.h>
#include "progmem.h"

/* Include this to get the TRAP() macro and access to the SendByte()
   function from the debug monitor. */

#include "monitor.h"

/*------------------------------------------------------------------*/
/* Print strings from progam memory                                 */
/*------------------------------------------------------------------*/

void sendprgstr(prog_char *s)
{
  char c;
  while ((c = PRG_RDB(s++)))
    SendByte(c);
}

/*------------------------------------------------------------------*/
/* 90s8515 (28 pins) and 90s8513 (20 pins)                          */
/*------------------------------------------------------------------*/

#if (AVR_AT90S8515 || AVR_AT90S2313)
void Test(void)
{
  unsigned char a = 0;

  /* Prints a message on the host monitor: */
  sendprgstr(PSTR("Hello from AVR!\n"));

  /* This is a source coded breakpoint: */
  TRAP();

  sbi(DDRB, PB0);   /* PB0 is output */
  sbi(DDRB, PB1);   /* PB1 is output */
  sbi(DDRB, PB2);   /* PB2 is output */
  sbi(DDRB, PB3);   /* PB3 is output */

  while(1) {
    TRAP();
    sendprgstr(PSTR("Loop!\n"));
    outp( (inp(PINB) & 0xf0) | (~a & 0x0f), PORTB);
    a++;
    if (a == 18) {
      TRAP();
      sendprgstr(PSTR("Reset!\n"));
      a = 0;
    }
  }
}
#endif /* (AVR_AT90S8515 || AVR_AT90S2313) */

/*------------------------------------------------------------------*/
/* 90s8523 (8 pins)                                                 */
/*------------------------------------------------------------------*/

#if AVR_AT90S2323
void Test(void)
{
  unsigned char a = 0;
  unsigned char b;

  /* Prints a message on the host monitor: */
  sendprgstr(PSTR("Hello from AVR!\n"));

  /* This is a source coded breakpoint: */
  TRAP();

  sbi(DDRB, PB3);   /* PB3 is output */
  sbi(DDRB, PB4);   /* PB4 is output */

  while(1) {
    TRAP();
    sendprgstr(PSTR("Loop!\n"));
    b = (inp(PINB) & 0xe7) | ((~a & 0x3) << 3);
    outp(b, PORTB);
    a++;
    if (a == 5) {
      TRAP();
      sendprgstr(PSTR("Reset!\n"));
      a = 0;
    }
  }
}
#endif /* AVR_AT90S2323 */

/*------------------------------------------------------------------*/

int main(void)
{
  Test();
  return 0;
}

